from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from .container import Container


class Subtitle:
    """A subtitle stream"""

    def __init__(self, container: 'Container', data: dict):
        self.container = container
        self.data = data

    @property
    def index(self) -> int:
        """The index of the stream"""
        return self.data['index']

    @property
    def disposition(self) -> str:
        """The properties of the stream as comma separated list as a string"""
        return ','.join(k for k, v in self.data['disposition'].items() if v)

    @property
    def codec(self) -> str:
        """The name of the codec"""
        return self.data.get('codec_name', 'und')

    @property
    def language(self) -> str:
        """The language of the stream of 'und'"""
        return self.data.get('tags', {}).get('language', 'und')

    @property
    def title(self) -> str:
        """The title of the stream"""
        return self.data.get('tags', {}).get('title', '')

    def to_dict(self) -> dict:
        return {
            'index': self.index,
            'disposition': self.disposition,
            'codec': self.codec,
            'language': self.language,
            'title': self.title,
        }
