from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from .container import Container


class Video:
    """A video stream"""

    def __init__(self, container: 'Container', data: dict):
        self.container = container
        self.data = data

    @property
    def fps(self) -> int:
        """The average frame rate as integer in frames per second"""
        fr = self.data['avg_frame_rate'].split('/')
        if int(fr[1]) == 0:
            return 0
        return round(int(fr[0]) / int(fr[1]))

    @property
    def codec(self) -> str:
        """The name of the codec"""
        return self.data.get('codec_name', '--Unknown--')

    @property
    def width(self) -> int:
        """The width"""
        return self.data['width']

    @property
    def height(self) -> int:
        """The height"""
        return self.data['height']

    @property
    def dimension(self) -> str:
        """The dimension in wxh"""
        return f'{self.width}x{self.height}'

    @property
    def aspect_ratio(self) -> str:
        """The display aspect ratio or N/A if not found"""
        return self.data.get('display_aspect_ratio', 'N/A')

    def to_dict(self) -> dict:
        return {
            'fps': self.fps,
            'codec': self.codec,
            'width': self.width,
            'height': self.height,
            'dimension': self.dimension,
            'aspect_ratio': self.aspect_ratio,
        }
